WitnessCommitment

Struct WitnessCommitment 

pub struct WitnessCommitment(/* private fields */);
A hash corresponding to the witness structure commitment in the coinbase transaction.

Implementations

Source

impl WitnessCommitment

pub fn from_raw_hash(inner: Hash) -> WitnessCommitment

Creates this wrapper type from the inner hash type.

pub fn to_raw_hash(self) -> Hash

Returns the inner hash (sha256, sh256d etc.).

pub fn as_raw_hash(&self) -> &Hash

Returns a reference to the inner hash (sha256, sh256d etc.).